#
from enigma import *
from Screens.Screen import Screen
from Screens.MessageBox import MessageBox
from Screens.InputBox import InputBox
from Screens.ChoiceBox import ChoiceBox
from Components.ActionMap import ActionMap, NumberActionMap
from Components.ScrollLabel import ScrollLabel
from Components.GUIComponent import *
from Components.MenuList import MenuList
from Components.Input import Input
from Screens.Console import Console
from Plugins.Plugin import PluginDescriptor
from Screens.ImageWizard import ImageWizard
from Plugins.Plugin import PluginDescriptor

import os

###############################################################################

er_path = "/usr/lib/enigma2/python/Plugins/Extensions/ER"
er_script = "/usr/lib/enigma2/python/Plugins/Extensions/ER/er.sh"
er_readme = "/usr/lib/enigma2/python/Plugins/Extensions/ER/readme.txt"

###############################################################################
# versionstring
###############################################################################
er_pluginversion = "B6.0"

###############################################################################
def main(session,**kwargs):
    try:    
     	session.open(Er)
    except:
        print "[ER] Pluginexecution failed"
###############################################################################
def autostart(reason,**kwargs):
    if reason == 0:
        print "[ER] no autostart"
###############################################################################
def Plugins(**kwargs):
    return PluginDescriptor(
        name="Emergency Recording", 
        description="plugin for Emergency Recording via Mediaserver", 
        where = PluginDescriptor.WHERE_PLUGINMENU,
        fnc = main
        )
###############################################################################
###############################################################################
class Er(Screen):
    skin = """
        <screen position="100,100" size="500,400" title="Emergency Recording Menu" >
            <widget name="menu" position="10,10" size="490,390" scrollbarMode="showOnDemand" />
        </screen>"""
        
    def __init__(self, session, args = 0):
        self.skin = Er.skin
        self.session = session
        Screen.__init__(self, session)
        self.menu = args
        list = []
        list.append((_("info if Mediaserver is running"), "info"))        
        list.append((_("show system time and delta ER is using"), "time"))        
        list.append((_("Changing UTC time delta ER is using"), "deltawizzard"))        
        list.append((_("restart options"), "restartwizzard"))
        list.append((_("install options (enable once before using !)"), "installwizzard"))
        list.append((_("help"), "help"))        
        list.append((_("man"), "man"))        
        list.append((_("about"), "about"))        
        self["menu"] = MenuList(list)
        self["actions"] = ActionMap(["WizardActions", "DirectionActions"],{"ok": self.go,"back": self.close,}, -1)
        
    def go(self):
        returnValue = self["menu"].l.getCurrentSelection()[1]
        if returnValue is not None:
           if returnValue is "info":
             self.session.open(Console,_("showing ER Info"),["%s info" % er_script])
           elif returnValue is "time":
             self.session.open(Console,_("showing UTC system time "),["%s time" % er_script])
           elif returnValue is "deltawizzard":
               DeltaWizzard(self.session)
           elif returnValue is "restartwizzard":
               RestartWizzard(self.session)
           elif returnValue is "installwizzard":
               InstallWizzard(self.session)
           elif returnValue is "man":
             self.session.open(Console,_("man shows readme.txt of ER"),["cat %s" % er_readme])
           elif returnValue is "help":
             self.session.open(Console,_("short help on ER commands"),["%s" % er_script])
           elif returnValue is "about":
             self.session.open(MessageBox,_("Emergency Recording Enigma2 Plugin %s\n\nER tool by thowi\n\nMediaserver by 3c5x9\n\nEnjoy adding Emergency Recordings with Mediaserver !" % er_pluginversion), MessageBox.TYPE_INFO)


###############################################################################
###############################################################################


class InstallWizzard(Screen):
    def __init__(self, session):
        self.session = session
        self.askForInstall()
        
    def askForInstall(self):
            self.session.openWithCallback(self.askForCommand,ChoiceBox,_("select Er install command to be executed"),self.getCommandList())

    def askForCommand(self,source):
        if source is None:
            self.skipInstall("no command passed, skipping install")
        else:
            self.source = source [1]
            self.session.openWithCallback(self.installCommand,MessageBox,_("are you sure to install ER with %s" % self.source), MessageBox.TYPE_YESNO)
            
    def installCommand(self,answer):
        if answer is None:
            self.skipInstall("answer is None")
        if answer is False:
            self.skipInstall("you were not confirming")
        else:
            self.session.open(Console,_("executing install command"),["%s %s" % (er_script,self.source)])
            
    def skipInstall(self,reason):
        self.session.open(MessageBox,_("install was canceled, because %s" % reason), MessageBox.TYPE_WARNING)
        
    def getCommandList(self):
        images = []
        images.append((_("enable  ER and Mediaserver daemon"),"enable"))
        images.append((_("disable ER and Mediaserver daemon"),"disable"))
        return images
        
###############################################################################
###############################################################################

class RestartWizzard(Screen):
    def __init__(self, session):
        self.session = session
        self.askForRestart()
        
    def askForRestart(self):
            self.session.openWithCallback(self.askForCommand,ChoiceBox,_("select restart command to be executed"),self.getCommandList())

    def askForCommand(self,source):
        if source is None:
            self.skipRestart("no command passed, skipping restart")
        else:
            self.source = source [1]
            self.session.openWithCallback(self.restartCommand,MessageBox,_("are you sure to %s" % self.source), MessageBox.TYPE_YESNO)
            
    def restartCommand(self,answer):
        if answer is None:
            self.skipRestart("answer is None")
        if answer is False:
            self.skipRestart("you were not confirming")
        else:
            title = "executing command on Dreambox"
            cmd = "%s %s"  % (er_script,self.source)
            self.session.open(Console,_(title),[cmd])
            
    def skipRestart(self,reason):
        self.session.open(MessageBox,_("restart was canceled, because %s" % reason), MessageBox.TYPE_WARNING)
        
    def getCommandList(self):
        images = []
        images.append((_("info if Mediaserver dameon is running"),"info"))
        images.append((_("start   Mediaserver daemon"),"start"))
        images.append((_("stop    Mediaserver daemon"),"stop"))
        images.append((_("restart Mediaserver dameon"),"restart"))
        images.append((_("reboot  Dreambox"),"reboot"))
        images.append((_("halt    Dreambox"),"halt"))
        images.append((_("restart Enigma on Dreambox"),"kill"))
        return images

###############################################################################
###############################################################################


class DeltaWizzard(Screen):
    def __init__(self, session):

        self.session = session
        self.askForDelta()
        
    def askForDelta(self):
	self.session.openWithCallback(self.ChangeDelta,InputBox, title=_("Please enter UTC time delta in hours"), text="0", maxSize=False, type=Input.TEXT)

    def ChangeDelta(self,answer):
        if answer is None:
            self.skipDelta("answer is None")
        if answer is False:
            self.skipDelta("you were not confirming")
        else:
            self.answer =  answer
            title = "Change UTC time delta to %s hours" %(self.answer)
            cmd = "%s delta %s" % (er_script,self.answer)
            self.session.open(Console,_(title),[cmd])
            
    def skipDelta(self,reason):
        self.session.open(MessageBox,_("Changing UTC time delta was canceled, because %s" % reason), MessageBox.TYPE_WARNING)

###############################################################################
###############################################################################

